echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[ ! -f /lib/libgudev-1.0.so ] && echo "Installing libgudev" && extension --install libgudev && echo "Finished libgudev"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v gi-inspect-typelib) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
	[[ $(command -v mbimcli) == "" ]] && echo "Installing libmbim" && extension --install libmbim && echo "Finished libmbim"
	[[ $(command -v qmicli) == "" ]] && echo "Installing libqmi" && extension --install libqmi && echo "Finished libqmi"
	[[ $(command -v polkitd) == "" ]] && echo "Installing polkit" && extension --install polkit && echo "Finished polkit"
	[[ $(command -v valac) == "" ]] && echo "Installing vala" && extension --install vala && echo "Finished vala"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v ModemManager) == "" ]]; then
	echo "modemmanager" 								>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "modemmanager" 								>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
